==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/stdio/StdioListFluent.java <==
package me.snowdrop.istio.mixer.adapter.stdio;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface StdioListFluent<A extends StdioListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,Stdio item);
    public A setToItems(int index,Stdio item);
    public A addToItems(Stdio... items);
    public A addAllToItems(Collection<Stdio> items);
    public A removeFromItems(Stdio... items);
    public A removeAllFromItems(Collection<Stdio> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Stdio> getItems();
    public List<Stdio> buildItems();
    public Stdio buildItem(int index);
    public Stdio buildFirstItem();
    public Stdio buildLastItem();
    public Stdio buildMatchingItem(Predicate<StdioBuilder> predicate);
    public A withItems(List<Stdio> items);
    public A withItems(Stdio... items);
    public Boolean hasItems();
    public StdioListFluent.ItemsNested<A> addNewItem();
    public StdioListFluent.ItemsNested<A> addNewItemLike(Stdio item);
    public StdioListFluent.ItemsNested<A> setNewItemLike(int index,Stdio item);
    public StdioListFluent.ItemsNested<A> editItem(int index);
    public StdioListFluent.ItemsNested<A> editFirstItem();
    public StdioListFluent.ItemsNested<A> editLastItem();
    public StdioListFluent.ItemsNested<A> editMatchingItem(Predicate<StdioBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,StdioFluent<StdioListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/stdio/StdioListFluent.java <==
package me.snowdrop.istio.mixer.adapter.stdio;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface StdioListFluent<A extends StdioListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Stdio item);
    public A setToItems(int index,Stdio item);
    public A addToItems(Stdio... items);
    public A addAllToItems(Collection<Stdio> items);
    public A removeFromItems(Stdio... items);
    public A removeAllFromItems(Collection<Stdio> items);
    public A removeMatchingFromItems(Predicate<StdioBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Stdio> getItems();
    public List<Stdio> buildItems();
    public Stdio buildItem(int index);
    public Stdio buildFirstItem();
    public Stdio buildLastItem();
    public Stdio buildMatchingItem(Predicate<StdioBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<StdioBuilder> predicate);
    public A withItems(List<Stdio> items);
    public A withItems(Stdio... items);
    public Boolean hasItems();
    public StdioListFluent.ItemsNested<A> addNewItem();
    public StdioListFluent.ItemsNested<A> addNewItemLike(Stdio item);
    public StdioListFluent.ItemsNested<A> setNewItemLike(int index,Stdio item);
    public StdioListFluent.ItemsNested<A> editItem(int index);
    public StdioListFluent.ItemsNested<A> editFirstItem();
    public StdioListFluent.ItemsNested<A> editLastItem();
    public StdioListFluent.ItemsNested<A> editMatchingItem(Predicate<StdioBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,StdioFluent<StdioListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
